@@ -7,12 +7,24 @@ use strict;
 use warnings;
 
 use Test::TAP::Model::Subtest::Visual;
+use URI::file;
 
 sub subtest_class { "Test::TAP::Model::Subtest::Visual" }
 
-sub str_status { $_[0]->ok ? "OK" : ($_[0]->bailed_out ? "BAILED OUT" : "FAILED") }
+sub str_status {
+	my $self = shift;
+	return "SKIPPED" if $self->skipped;
+	return "BAILED OUT" if $self->bailed_out;
 
-sub link { $_[0]->name }
+	return "OK"
+		if $self->ok
+		and $self->actual_cases == $self->planned
+		and $self->actual_cases > 0;
+
+	return "FAILED";
+}
+
+sub link { URI::file->new($_[0]->name) }
 
 sub case_rows {
 	my $self = shift;
